#!/usr/bin/env bash

LIB_DIR=/var/lib
PHYLODB_DIR=$LIB_DIR/phyloalps/phylodb
PHYLODUMP_DIR=$LIB_DIR/phyloalps/phylodump

# Config
echo 'GEOS_LIBRARY_PATH = "/run/current-system/sw/lib/libgeos_c.so"' >> $PHYLODB_DIR/phylodb/settings.py
echo 'GDAL_LIBRARY_PATH = "/run/current-system/sw/lib/libgdal.so"' >> $PHYLODB_DIR/phylodb/settings.py

# Disable CSRF cookie as we will use non-secure http
perl -pi -e "s/CSRF_COOKIE_SECURE.*=.*/CSRF_COOKIE_SECURE = False/" $PHYLODB_DIR/phylodb/settings.py

# For the fake authentication to work
perl -pi -e "s/django.contrib.auth.middleware.AuthenticationMiddleware',$/django.contrib.auth.middleware.AuthenticationMiddleware','django.contrib.auth.middleware.RemoteUserMiddleware',/" $PHYLODB_DIR/phylodb/settings.py
#echo "AUTHENTICATION_BACKENDS = [ 'django.contrib.auth.backends.RemoteUserBackend' ]" >> $PHYLODB_DIR/phylodb/settings.py

# Django install
cd $LIB_DIR/django
if [ \! -d phylodbenv ]
then
  virtualenv -p python3 phylodbenv
fi
source phylodbenv/bin/activate
pip install django
pip install ply
pip install sparqlwrapper
pip install django-debug-toolbar
pip install django-widget-tweaks
pip install -I gunicorn

# Create the postgis extension into DBs (must be superuser)
sudo -u postgres psql -d editor_db -c "CREATE EXTENSION IF NOT EXISTS postgis"
sudo -u postgres psql -d browser_db -c "CREATE EXTENSION IF NOT EXISTS postgis"

# Create the databases schema
cd $PHYLODB_DIR
python3 manage.py makemigrations
python3 manage.py migrate
python3 manage.py migrate --database=browser_db

# Database initial data
if [ \! -f $PHYLODB_DIR/initdb.done ]
then
  # Init the superuser
  echo "from django.contrib.auth import get_user_model; User = get_user_model(); User.objects.create_superuser('admin', 'gridmaster@univ-grenoble-alpes.fr', 'phylodev')" | python3 manage.py shell

  # Load data
  if [ -f $PHYLODUMP_DIR/editor_db.json ]
  then
    ## Loading from a dump
    echo "Dump found, loading it..."
    python3 manage.py loaddata $PHYLODUMP_DIR/editor_db.json
    python3 manage.py loaddata --database=browser_db $PHYLODUMP_DIR/browser_db.json
  else
    ## Direct loading
    # Load sample data
    latest_sample=`ls samples/*[0-9].csv|sort -n|tail -1`
    sudo -u phyloalps python3 install/load_sampling_data.py $latest_sample browser_db phylobrowser
    sudo -u phyloalps python3 install/load_sampling_data.py $latest_sample editor_db phyloeditor

    # Reverse geocode the samples GPS coordinates
    #sudo -u phyloalps python3 install/reverse_geocode.py browser_db phylobrowser
    #sudo -u phyloalps python3 install/reverse_geocode.py editor_db phyloeditor

    # Load the genomic data
    #sudo -u phyloalps python3 install/load_genomic_data.py browser_db phylobrowser
    #sudo -u phyloalps python3 install/load_genomic_data.py editor_db phyloeditor
  fi
  touch $PHYLODB_DIR/initdb.done
fi

# Download the project dependencies
if [ \! -d phylodb/static/deps/bulma* ]
then
  cd phylodb/static/deps
  source deps.sh
fi

# Generate CSS files from SASS files
cd $PHYLODB_DIR
if [ \! -f phylobrowser/static/css/browser.css ]
then
  sass phylobrowser/static/sass/browser.sass phylobrowser/static/css/browser.css
  sass phyloeditor/static/sass/editor.sass phyloeditor/static/css/editor.css
  sass phylohome/static/sass/home.sass phylohome/static/css/home.css
fi

# Copy static files and grant permissions to httpd
if [ \! -f $PHYLODB_DIR/static/css/home.css ]
then
  python3 manage.py collectstatic
  chown -R wwwrun:wwwrun $PHYLODB_DIR/static
  chmod -R 775 $PHYLODB_DIR/static
fi

# Start Gunicon WSGI server on port 8888
ps awux |grep gunicorn|grep -v grep|awk '{print "kill " $2}'|bash
nohup gunicorn -e REMOTE_USER=admin -b :8888 phylodb.wsgi&
